==> attal_0.8.orig.tar.gz: attal-0.8/i18n/it/attal_client_it.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>ClientInterface</name>
    <message>
        <source>Attal - Lords of Doom</source>
        <translation>Attal - Signori del Destino</translation>
    </message>
    <message>
        <source>Connect to server</source>
        <translation>Collegamento al server</translation>
    </message>
    <message>
        <source>&amp;Connect to server</source>
        <translation>&amp;Collegamento al server</translation>
    </message>
    <message>
        <source>CTRL+C</source>
        <translation>CTRL+C</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Disconnessione</translation>
    </message>
    <message>
        <source>&amp;Disconnect</source>
        <translation>&amp;Disconnessione</translation>
    </message>
    <message>
        <source>CTRL+D</source>
        <translation>CTRL+D</translation>
    </message>
    <message>
        <source>Mini map</source>
        <translation>Mini mappa</translation>
    </message>
    <message>
        <source>&amp;Mini map</source>
        <translation>&amp;Mini mappa</translation>
    </message>
    <message>
        <source>CTRL+M</source>
        <translation>CTRL+M</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <source>CTRL+Q</source>
        <translation>CTRL+Q</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Gioco</translation>
    </message>
    <message>
        <source>Can&apos;t connect</source>
        <translation>Non posso connettermi</translation>
    </message>
    <message>
        <source>You&apos;re already connected to a server. Please disconnect first.</source>
        <translation>Sei già connesso ad un server, per piacere disconnettiti</translation>
    </message>
    <message>
        <source>Match</source>
        <translation>Partita</translation>
    </message>
    <message>
        <source>Do you want abandon the match ?</source>
        <translation>Vuoi abbandonare la partita?</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Barra di stato</translation>
    </message>
    <message>
        <source>Tab window</source>
        <translation>Finestra a linguette</translation>
    </message>
    <message>
        <source>&amp;Tab Window</source>
        <translation>&amp;Finestra a linguette</translation>
    </message>
    <message>
        <source>CTRL+T</source>
        <translation>CTRL+T</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Schermo Intero</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Schermo Intero</translation>
    </message>
    <message>
        <source>CTRL+F</source>
        <translation>CTRL+F</translation>
    </message>
</context>
<context>
    <name>ConfigConnection</name>
    <message>
        <source>Connection to server</source>
        <translation>Collegamento al server</translation>
    </message>
    <message>
        <source>Host : </source>
        <translation>Host:</translation>
    </message>
    <message>
        <source>Port : </source>
        <translation>Porta : </translation>
    </message>
    <message>
        <source>Name : </source>
        <translation>Nome : </translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Collega</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancella</translation>
    </message>
</context>
</TS>

==> attal_0.9.1.orig.tar.gz: attal-0.9.1/i18n/it/attal_client_it.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>ClientInterface</name>
    <message>
        <source>Attal - Lords of Doom</source>
        <translation>Attal - Signori del Destino</translation>
    </message>
    <message>
        <source>Connect to server</source>
        <translation>Collegamento al server</translation>
    </message>
    <message>
        <source>&amp;Connect to server</source>
        <translation>&amp;Collegamento al server</translation>
    </message>
    <message>
        <source>CTRL+C</source>
        <translation>CTRL+C</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Disconnessione</translation>
    </message>
    <message>
        <source>&amp;Disconnect</source>
        <translation>&amp;Disconnessione</translation>
    </message>
    <message>
        <source>CTRL+D</source>
        <translation>CTRL+D</translation>
    </message>
    <message>
        <source>Mini map</source>
        <translation>Mini mappa</translation>
    </message>
    <message>
        <source>&amp;Mini map</source>
        <translation>&amp;Mini mappa</translation>
    </message>
    <message>
        <source>CTRL+M</source>
        <translation>CTRL+M</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <source>CTRL+Q</source>
        <translation>CTRL+Q</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Gioco</translation>
    </message>
    <message>
        <source>Can&apos;t connect</source>
        <translation>Non posso connettermi</translation>
    </message>
    <message>
        <source>You&apos;re already connected to a server. Please disconnect first.</source>
        <translation>Sei già connesso ad un server, per piacere disconnettiti</translation>
    </message>
    <message>
        <source>Match</source>
        <translation>Partita</translation>
    </message>
    <message>
        <source>Do you want abandon the match ?</source>
        <translation>Vuoi abbandonare la partita?</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Barra di stato</translation>
    </message>
    <message>
        <source>Tab window</source>
        <translation>Finestra a linguette</translation>
    </message>
    <message>
        <source>&amp;Tab Window</source>
        <translation>&amp;Finestra a linguette</translation>
    </message>
    <message>
        <source>CTRL+T</source>
        <translation>CTRL+T</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Schermo Intero</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Schermo Intero</translation>
    </message>
    <message>
        <source>CTRL+F</source>
        <translation>CTRL+F</translation>
    </message>
    <message>
        <source>Can&apos;t load theme</source>
        <translation>Non posso caricare il tema</translation>
    </message>
    <message>
        <source>Theme </source>
        <translation>Il tema </translation>
    </message>
    <message>
        <source> has not been loaded successfully</source>
        <translation> non è stato caricato con successo</translation>
    </message>
    <message>
        <source>Fast Server </source>
        <translation>Server</translation>
    </message>
    <message>
        <source>Fast &amp;Server</source>
        <translation>&amp;Server</translation>
    </message>
    <message>
        <source>CTRL+S</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ConfigConnection</name>
    <message>
        <source>Connection to server</source>
        <translation>Collegamento al server</translation>
    </message>
    <message>
        <source>Host : </source>
        <translation>Host:</translation>
    </message>
    <message>
        <source>Port : </source>
        <translation>Porta : </translation>
    </message>
    <message>
        <source>Name : </source>
        <translation>Nome : </translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Collega</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
</TS>
